<?php

namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\DTO\{ Response, Request };
use Zeedhi\Framework\DataSource\DataSet;

use Ems\portalGestor\Util\HcmServices;

class HcmServicesController {

    /** @var HcmServices */
    protected $hcmServices;

    /** @var InstanceManager */
    protected $instanceManager;
    
    public function __construct(
        HcmServices $hcmServices
    ) {
        $this->hcmServices = $hcmServices;
        $this->instanceManager = InstanceManager::getInstance();
    }

    public function fowardToHcmservices(
        Request $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            $route = substr($request->getRoutePath(), 1);
            $nrOrg = $row['NRORG'];
            
            $row = $this->buildRow($request);
            $row['NRORG'] = $nrOrg;
    
            $params = [
                'requestType' => 'Row',
                'row' => $row,
            ];
    
            $result = $this->hcmServices->send($route, $params, $nrOrg);

            $data = $result['dataset'][$route] ??
                $result['dataset']['data'] ??
                null;
            if (is_null($data)) {
                return;
            }
            
            $response->addDataSet(new DataSet('data', $data));
        } catch (ExpectedException $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    private function buildRow(
        Request $request
    ): array {
        switch (get_class($request)) {
            case Request\Filter::class:
                $row = $request->getParameters();
                unset($row['requestType']);
                return $row;
            case Request\Row::class:
                return $request->getRow()->getArrayCopy();
        }
    }
}